@@ -29,6 +29,7 @@
 #include <panel-applet-gconf.h>
 #include <libgnomeui/gnome-about.h>
 #include <gconf/gconf-client.h>
+#include <gdk/gdkkeysyms.h>
 
 #include "netstatus-icon.h"
 #include "netstatus-iface.h"
@@ -47,18 +48,20 @@ struct _NetstatusAppletPrivate
   guint           notify_id;
 };
 
-static void netstatus_applet_instance_init             (NetstatusApplet      *applet,
-							NetstatusAppletClass *klass);
-static void netstatus_applet_class_init                (NetstatusAppletClass *klass);
-static void netstatus_applet_finalize                  (GObject              *object);
-static void netstatus_applet_orientation_changed       (NetstatusApplet      *applet,
-							PanelAppletOrient     orient);
-static void netstatus_applet_display_about_dialog      (BonoboUIComponent    *uic,
-							NetstatusApplet      *applet);
-static void netstatus_applet_display_properties_dialog (BonoboUIComponent    *uic,
-							NetstatusApplet      *applet);
-static void netstatus_applet_display_status_dialog     (NetstatusApplet      *applet);
-static void netstatus_applet_iface_name_changed        (NetstatusApplet      *applet);
+static void     netstatus_applet_instance_init             (NetstatusApplet      *applet,
+							    NetstatusAppletClass *klass);
+static void     netstatus_applet_class_init                (NetstatusAppletClass *klass);
+static void     netstatus_applet_finalize                  (GObject              *object);
+static gboolean netstatus_applet_key_press_event           (GtkWidget            *widget,
+							    GdkEventKey          *event);
+static void     netstatus_applet_orientation_changed       (NetstatusApplet      *applet,
+							    PanelAppletOrient     orient);
+static void     netstatus_applet_display_about_dialog      (BonoboUIComponent    *uic,
+							    NetstatusApplet      *applet);
+static void     netstatus_applet_display_properties_dialog (BonoboUIComponent    *uic,
+							    NetstatusApplet      *applet);
+static void     netstatus_applet_display_status_dialog     (NetstatusApplet      *applet);
+static void     netstatus_applet_iface_name_changed        (NetstatusApplet      *applet);
 
 static GObjectClass *parent_class;
 
@@ -130,11 +133,14 @@ netstatus_applet_instance_init (NetstatusApplet      *applet,
 static void
 netstatus_applet_class_init (NetstatusAppletClass *klass)
 {
-  GObjectClass *gobject_class = (GObjectClass *) klass;
+  GObjectClass *gobject_class  = (GObjectClass *) klass;
+  GtkWidgetClass *widget_class = (GtkWidgetClass *) klass;
 
   parent_class = g_type_class_peek_parent (klass);
 
   gobject_class->finalize = netstatus_applet_finalize;
+
+  widget_class->key_press_event = netstatus_applet_key_press_event;
 }
 
 static void
@@ -168,6 +174,27 @@ netstatus_applet_finalize (GObject *object)
   parent_class->finalize (object);
 }
 
+static gboolean
+netstatus_applet_key_press_event (GtkWidget   *widget,
+				  GdkEventKey *event)
+{
+  NetstatusApplet *applet = (NetstatusApplet *) widget;
+
+  switch (event->keyval)
+    {
+    case GDK_space:
+    case GDK_KP_Space:
+    case GDK_Return:
+    case GDK_KP_Enter:
+    case GDK_ISO_Enter:
+    case GDK_3270_Enter:
+      netstatus_icon_invoke (NETSTATUS_ICON (applet->priv->icon));
+      return TRUE;
+    default:
+      return FALSE;
+    }
+}
+
 static void
 netstatus_applet_display_properties_dialog (BonoboUIComponent *uic,
 					    NetstatusApplet   *applet)
